Module: EagleClaw::Browser
- Included in:
- Scraper
- Defined in:
- lib/eagleclaw/browser.rb
Overview
Add browsing capabilities to a class.
Instance Method Summary collapse
-
#agent ⇒ Mechanize
This browser's
Mechanizeagent. -
#method_missing(name, *args, &block) ⇒ Object
If a non-existent method is called, pass it along to the
Mechanizeagent.
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(name, *args, &block) ⇒ Object
If a non-existent method is called, pass it along to the Mechanize
agent.
20 21 22 |
# File 'lib/eagleclaw/browser.rb', line 20 def method_missing(name, *args, &block) agent.send(name, *args, &block) end |
Instance Method Details
#agent ⇒ Mechanize
This browser's Mechanize agent.
13 14 15 |
# File 'lib/eagleclaw/browser.rb', line 13 def agent @agent ||= Mechanize.new end |